% [img_sc,microns_per_pixel] = scan_conversion(img,fs,probe,x,y,line_density,scale,speed_of_sound,steer_angle,extension_angle)
%
% Function for scan conversion. Only works for linear and curved linear
% arrays.
%
% This function needs information about the probe. This can be specified in
% 2 different ways:
%
%   1. Specifiy the probe ID, then the function will open the probes.lst
%   file and find the probe info there. The path to the probes.lst file
%   must be given compile time through the define _PROBES_LST_PATH_.
%   Preferably this could be ".", i.e the same folder as the mex file.
% 
%   2. Give a probe struct containing the following fields
%       id,type(0=CLA,2=LA/PA),elements,radius,pitch,maxsteerangle,transmitoffset 	
%
% Input : 
% img               - Image to be scan converted
% fs                - Sampling frequency of input
% probe             - Probe id or probe struct. The probe struct must have the
% fields specified above;
% x                 - Width of scan converted image
% y                 - Height of scanconverted image
% line_density      - Line density
% scale	 	    - (Optional) The output pixel size in um. If not supplied or [], the function computes the "optimal" scale.
% speed_of_sound    - (Optional) Speed of sound (Default 1540)
% steer_angle       - (Optional) Steer angle (Default = 0)
% extension_angle   - (Optional) Extension angle. Needed for phased arrays (Default = 0).
%
% Output :
% img_sc            - scan converted image
% scale		    - microns per pixel